<?php

/**
* Source code by Adrian Gaudebert - http://adrian.gaudebert.fr - adrian@gaudebert.fr
* No licence, you can do whatever you want with that code
*/

header('Content-Type: text/html; charset=UTF-8');

/**
* Replace links (like http:// or www.) in a text by html links (<a href=""></a>)
*/
function replace_text_url($message)
{
    return preg_replace("`\b(https?|ftp|file)://[-A-Za-z0-9+&@#/%?=~_|!:,.;]*[-A-Za-z0-9+&@#/%=~_|]\b`", '<a href="\0">\0</a>', $message);
}

/**
* Replace twitter user names (@user) in a text by html links (<a href="http://twitter.com/user>)
*/
function replace_twitter_user_names($tweet)
{
    return preg_replace('#\@([-A-Za-z0-9]+)#', '<a href="http://twitter.com/$1">@$1</a>', $tweet);
}

/**
* Return a french formatted date from a timestamp, in a user friendly format
* @author http://www.siteduzero.com/forum-83-368806-3410284-calcul-du-temps-en-heure-minute-seconde.html#r3410284
*/
function format_date_diff($time)
{
	$diff = time()-$time;
	if($diff<0) return false;
	
	$sec = $diff%60;
	$min = ($diff-$sec)/60%60;
	$heure = ($diff-$sec-$min*60)/3600%24;

	$minuit = mktime('0','0','0',date('m'),date('d'),date('Y'));
	$hier = mktime('0','0','0',date('m'),date('d')-1,date('Y'));

	if($diff<60) { return "Il y a ".$diff."s"; }
	elseif($diff<3600) { return "Il y a ".$min." min"; }
	elseif($diff<7200) { return "Il y a ".$heure."h".$min; }
	elseif($time>$minuit) { return "Aujourd'hui à ".date("H:i",$time); }
	elseif($time>$hier) { return "Hier à ".date("H:i",$time); }
	else { return "Le ".date('d/m/Y \à H:i:s',$time); }
}

/**
* Get the last tweets of a twitter user
* @param $login User name
* @param $nbTweets Number of statuses to get
* @return Array of statuses, each status has keys "text", "date" and "id"
*/
function get_last_tweets($login, $nbTweets)
{
    $tweets = array();
    
    if ($file = @file_get_contents("http://www.twitter.com/statuses/user_timeline.json?screen_name=".$login."&count=".$nbTweets))
    {
        $tab = json_decode($file);

        foreach ($tab as $status)
        {
            $tweets[] = array(
                'text' => replace_twitter_user_names(replace_text_url($status->text)),
                'date' => format_date_diff(strtotime($status->created_at)),
                'id'   => $status->id,
            );
        }
    }
    else
    {
        $tweets[] = array(
            'text' => "Access to this user's tweets is denied",
            'date' => '',
            'id'   => '',
        );
    }
    
    return $tweets;
}

// using the script is that simple :
$twitter_user = 'AdrianGaudebert';
$tweets = get_last_tweets($twitter_user, 5);

/*  $tweets contains an array of arrays, something like that : 
    $tweets = array(
        "0" => array(
            "text" => "status 1",
            "date" => "Il y a ...",
            "id" => 1234567890,
        ), 
        "1" => array(
            "text" => "status 2",
            "date" => "Il y a ...",
            "id" => 1234567891,
        ), 
    );
*/

/* Here is an example for CSS and HTML use of this script : */

?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fr" >
	<head>
		<title></title>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<style type="text/css">
#twitter_live
{
    border: 1px dotted black;
    padding: 7px;
}
#twitter_live h1
{
    color: blue;
    font-size: 1.2em;
    border-bottom: 2px solid black;
}
#twitter_live .status
{
    padding: 5px;
    border-bottom: 1px dotted black;
}
#twitter_live .status .status-text
{
}
#twitter_live .status .status-date
{
    font-size: 0.8em;
    font-style: italic;
}
		</style>
	</head>
	<body>
	    <div id="twitter_live">
	        <h1><?php echo $twitter_user; ?>'s Twitter Live</h1>
	        <?php foreach ($tweets as $tweet) { ?>
	        <div class="status">
	            <span class="status-text"><?php echo $tweet['text']; ?></span>
	            <span class="status-date"><a href="http://twitter.com/<?php echo $twitter_user; ?>/status/<?php echo $tweet['id']; ?>"><?php echo $tweet['date']; ?></a></span>
            </div>
	        <?php } ?>
        </div>
        <p>
            <a href="http://adrian.gaudebert.fr/labs/twitter/twitter_live.zip">Download the source code / Téléchargez le code source</a>
        </p>
	</body>
</html>
